@@ -15,7 +15,7 @@ start.run <- Sys.time()
 califlopp(file=file, dispf=dispf, param = param, resfile = resfile)
 end.run <- Sys.time()
 duration <- end.run - start.run
-print(duration)
+# print(duration)
 
 
 #calcul avec RCALI grid sur un couple
@@ -30,7 +30,7 @@ start.run <- Sys.time()
 califlopp(file=file, dispf=dispf, param = param, resfile = resfile)
 end.run <- Sys.time()
 duration <- end.run - start.run
-print(duration)
+# print(duration)
 
 
 # Charger le fichier de rsultats cub
@@ -41,7 +41,7 @@ start.run <- Sys.time()
 dispcub.res <- getRes("paysage.cubres")
 end.run <- Sys.time()
 duration <- end.run - start.run
-print(duration)
+# print(duration)
 
 #avec un read.table
 cat("avec un read.table\n")
@@ -49,4 +49,4 @@ start.run <- Sys.time()
 dispcubtab.res <- read.table("paysage.cubres", skip=1)
 end.run <- Sys.time()
 duration <- end.run - start.run
-print(duration)
+# print(duration)
